"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.updatePageValidation = exports.updatePageSettingsValidation = exports.createPageValidation = exports.createPageUpdateValidation = exports.createPageSettingsUpdateValidation = exports.createPageCreateValidation = void 0;
var _normalizePath = _interopRequireDefault(require("./normalizePath"));
var _zod = _interopRequireDefault(require("zod"));
const createPageValidation = _zod.default.object({
  category: _zod.default.string().max(500)
});
exports.createPageValidation = createPageValidation;
const createPageCreateValidation = () => {
  return createPageValidation;
};
exports.createPageCreateValidation = createPageCreateValidation;
const updatePageSettingsValidation = _zod.default.object({
  general: _zod.default.object({
    tags: _zod.default.array(_zod.default.string().max(50)).max(30, "Cannot store more than 30 tags.").nullish().optional(),
    snippet: _zod.default.string().max(500).nullish().optional().transform(value => value || undefined),
    layout: _zod.default.string().max(50).nullish().optional().transform(value => value || undefined),
    image: _zod.default.object({
      id: _zod.default.string(),
      src: _zod.default.string()
    }).passthrough().nullish().transform(value => value || undefined)
  }).passthrough().partial(),
  seo: _zod.default.object({
    title: _zod.default.string().max(500).optional().nullish(),
    description: _zod.default.string().max(500).optional().nullish(),
    meta: _zod.default.array(_zod.default.object({
      name: _zod.default.string().max(100),
      content: _zod.default.string().max(200)
    })).max(30, "Cannot store more than 30 SEO tags.").nullish().optional().transform(value => value || [])
  }).passthrough().partial(),
  social: _zod.default.object({
    title: _zod.default.string().max(500).optional().nullish(),
    description: _zod.default.string().max(500).optional().nullish(),
    meta: _zod.default.array(_zod.default.object({
      property: _zod.default.string().max(100),
      content: _zod.default.string().max(200)
    })).max(30, "Cannot store more than 30 social tags.").optional().nullish().transform(value => value || []),
    image: _zod.default.object({
      id: _zod.default.string(),
      src: _zod.default.string()
    }).passthrough().optional().nullish()
  }).passthrough().partial()
}).passthrough().partial();
exports.updatePageSettingsValidation = updatePageSettingsValidation;
const updatePageValidation = _zod.default.object({
  title: _zod.default.string().max(500),
  path: _zod.default.string().min(2).max(500).nullish().transform(value => {
    if (!value) {
      return undefined;
    }
    return (0, _normalizePath.default)(value);
  }),
  category: _zod.default.string().max(500),
  /**
   * We need to allow everything through the content object.
   */
  settings: updatePageSettingsValidation,
  content: _zod.default.union([_zod.default.object({}).passthrough(), _zod.default.array(_zod.default.object({}).passthrough())]).optional().nullish()
}).partial();
exports.updatePageValidation = updatePageValidation;
const createPageUpdateValidation = () => {
  return updatePageValidation;
};
exports.createPageUpdateValidation = createPageUpdateValidation;
const createPageSettingsUpdateValidation = () => {
  return updatePageSettingsValidation;
};
exports.createPageSettingsUpdateValidation = createPageSettingsUpdateValidation;

//# sourceMappingURL=validation.js.map